(function() {

    tinymce.PluginManager.add('soc_shortcodes', function( editor, url ) {

        let buttons   = soc_tinymce_data.buttons;
        let icons     = soc_tinymce_data.icons;
        let baseURL   = soc_tinymce_data.baseURL;

        // Read and sort buttons
        var buttons_menu = [];
        for (let obj in buttons) {
            if (buttons.hasOwnProperty(obj)) {
                let button_colour = obj;
                let button_size   = buttons[obj];
                let button_size_menu = [];
                for (let i = 0; i < button_size.length; i++) {
                    let size = {
                        text: button_size[i],
                        classes: `soc-btn-${button_size[i]}`,
                        onclick: function() {
                            editor.insertContent(`[soc_button color='${button_colour}' size='${button_size[i]}' href='#' target='new' align='left' rel='']Button[/soc_button]`);
                        }
                    };
                    button_size_menu.push(size);
                }
                let colour = {
                    text: obj,
                    icon: `custom-btn-${button_colour}`,
                    menu: button_size_menu
                };
                buttons_menu.push(colour);
            }
        }

        // Read and sort icons
        var icons_menu = [];
        for (let obj in icons) {
            if (icons.hasOwnProperty(obj)) {
                let size = {
                    text: obj,
                    icon: icons[obj].icon,
                    onclick: function() {
                        editor.insertContent(`${icons[obj].code}`);
                    }
                };
                icons_menu.push(size);
            }
        }


        let groups     = [
            {
                text: 'Buttons',
                icon: 'fa fa-square',
                menu: buttons_menu
            },
            {
                text: 'Panels',
                icon: 'fa fa-navicon',
                menu: [
                    {
                        text: 'Blue Panel',
                        onclick: function() {
                            editor.insertContent(`[soc_panel color="blue"]Text in panel[/soc_panel]`);
                        }
                    },
                    {
                        text: 'Gray Panel',
                        onclick: function() {
                            editor.insertContent(`[soc_panel color="gray"]Text in panel[/soc_panel]`);
                        }
                    },
                    {
                        text: 'Green Panel',
                        onclick: function() {
                            editor.insertContent(`[soc_panel color="green"]Text in panel[/soc_panel]`);
                        }
                    },
                    {
                        text: 'Red Panel',
                        onclick: function() {
                            editor.insertContent(`[soc_panel color="red"]Text in panel[/soc_panel]`);
                        }
                    },
                    {
                        text: 'Yellow Panel',
                        onclick: function() {
                            editor.insertContent(`[soc_panel color="yellow"]Text in panel[/soc_panel]`);
                        }
                    },
                    {
                        text: 'Orange Panel',
                        onclick: function() {
                            editor.insertContent(`[soc_panel color="orange"]Text in panel[/soc_panel]`);
                        }
                    },
                    {
                        text: 'White Panel',
                        onclick: function() {
                            editor.insertContent(`[soc_panel color="white"]Text in panel[/soc_panel]`);
                        }
                    }
                ]
            },
            {
                text: 'Dividers/Spacers',
                icon: 'fa fa-minus',
                menu: [
                     {
                        classes: "soc-divider-type1",
                        onclick: function() {
                            editor.insertContent(`[soc_divider margin_top="25" color="#fff"]`);
                        }
                    },
					{
                        classes: "soc-divider-type2",
                        onclick: function() {
                            editor.insertContent(`[soc_divider height="1"]`);
                        }
                    },
                    {
                        classes: "soc-divider-type3",
                        onclick: function() {
                            editor.insertContent(`[soc_divider height="2" margin_top="25" margin_bottom="25" color="#999"]`);
                        }
                    },
                    {
                        classes: "soc-divider-type4",
                        onclick: function() {
                            editor.insertContent(`[soc_divider height="5" margin_top="50" margin_bottom="50" color="#cc0000"]`);
                        }
                    }
                ]
            },
            {
               text: 'Clear Space',
                onclick: function() {
                    editor.insertContent(`[soc_divider height="0" margin_top="50"]`);
                }
            },
            {
                text: 'Columns',
                icon: 'fa fa-columns',
                menu: [
                    {
                        text: '1/2 | 1/2',
                        selector: 'tr',
                        onclick: function() {
                            editor.insertContent(`  [soc_one_half] content [/soc_one_half]
                                                    [soc_one_half class='last'] content [/soc_one_half]`);
                        }
                    },
                    {
                        text: '1/3 | 1/3  | 1/3',
                        onclick: function() {
                            editor.insertContent(`  [soc_one_third] content [/soc_one_third]
                                                    [soc_one_third ] content [/soc_one_third]
                                                    [soc_one_third class='last'] content [/soc_one_third]`);
                        }
                    },
					 {
                        text: '1/3 2/3',
                        onclick: function() {
                            editor.insertContent(`  [soc_one_third] content [/soc_one_third]
                                                    [soc_two_third class='last'] content [/soc_two_third]`);
                        }
                    },
                    {
                        text: '2/3 1/3',
                        onclick: function() {
                            editor.insertContent(`  [soc_two_third] content [/soc_two_third]
                                                    [soc_one_third class='last'] content [/soc_one_third]`);
                        }
                    },
                    {
                        text: '1/4 1/4 1/4 1/4',
                        onclick: function() {
                            editor.insertContent(`  [soc_one_fourth] content [/soc_one_fourth]
                                                    [soc_one_fourth] content [/soc_one_fourth]
                                                    [soc_one_fourth] content [/soc_one_fourth]
                                                    [soc_one_fourth class='last'] content [/soc_one_fourth]`);
                        }
                    },
					 {
                        text: '1/4 3/4',
                        onclick: function() {
                            editor.insertContent(`  [soc_one_fourth] content [/soc_one_fourth]
                                                    [soc_three_fourth class='last'] content [/soc_three_fourth]`);
                        }
                    },
                    {
                        text: '3/4 1/4',
                        onclick: function() {
                            editor.insertContent(`  [soc_three_fourth]3/4 Text[/soc_three_fourth]
                                                    [soc_one_fourth class='last']1/4 Text[/soc_one_fourth]`);
                        }
                    },
                    {
                        text: '1/5 1/5 1/5 1/5 1/5',
                        onclick: function() {
                            editor.insertContent(`  [soc_one_fifth] content [/soc_one_fifth]
                                                    [soc_one_fifth] content [/soc_one_fifth]
                                                    [soc_one_fifth] content [/soc_one_fifth]
                                                    [soc_one_fifth] content [/soc_one_fifth]
                                                    [soc_one_fifth class='last'] content [/soc_one_fifth]`);
                        }
                    }
                ]
            },
            {
                text: 'Font Awesome Icons',
                icon: 'fa fa-search',
                menu: icons_menu
            },
            {
                text: 'Protection',
                icon: 'fa fa-warning',
                menu: [
                    {
                        text: 'Is Member',
                        onclick: function() {
                            editor.insertContent(`[soc_member]Content for members - See Documentation for more options.[/soc_member]`);
                        }
                    },
                    {
                        text: 'Is Visitor',
                        onclick: function() {
                            editor.insertContent(`[soc_visitor]Content for visitors[/soc_visitor]`);
                        }
                    }
                ]
            },
            {
                text: 'Lorem Content',
                icon: 'fa fa-file-text-o',
                onclick: function() {
                    editor.insertContent(`Lorem ipsum dolor sit amet, consectetur adipiscing elit. Donec nec nulla vitae lacus mattis volutpat eu at sapien. Nunc interdum congue libero, quis laoreet elit sagittis ut. Pellentesque lacus erat, dictum condimentum pharetra vel, malesuada volutpat risus. Nunc sit amet risus dolor. Etiam posuere tellus nisl. Integer lorem ligula, tempor eu laoreet ac, eleifend quis diam. Proin cursus, nibh eu vehicula varius, lacus elit eleifend elit, eget commodo ante felis at neque.`);
                }
            },
            {
                text: 'Testimonial',
                icon: 'fa fa-comment',
                onclick: function() {
                    editor.insertContent(`[soc_testimonial image="SMALL_IMAGE_URL_TEXT_MODE" name="John Doe" max_width="500" stars="5"]Testimonial content[/soc_testimonial]`);
                }
            },
            {
                text: 'Headline',
                icon: 'fa fa-font',
                onclick: function() {
                    editor.insertContent(`[soc_headline color="#000" font_size="40" font_size_tablet="30" font_size_phone="20" shadow="0" align="center" margin_top="25" margin_bottom="25" element="h2"]Heading text[/soc_headline]`);
                }
            },
            {
                text: 'Hero Banner',
                icon: 'fa fa-image',
                onclick: function() {
                    editor.insertContent(`[soc_hero_banner parallax="1" height="auto" min_height="0" margin_top="0" margin_bottom="25" margin_left="0" margin_right="0" padding_top="25" padding_bottom="25" padding_left="25" padding_right="25" bgimage="INSERT_URL_HERE"]Banner text[/soc_hero_banner]`);
                }
            },
            {
                text: 'Full Section',
                icon: 'fa fa-arrows-h',
                onclick: function() {
                    editor.insertContent(`[soc_full_section bgcolor="#f4f4f4" textcolor="#444" bgimage="IMAGE_URL_TEXT_MODE" parallax="1" margin_top="0" margin_bottom="0" margin_left="0" margin_right="0" padding_top="25" padding_bottom="25" padding_left="0" padding_right="0"]Section content[/soc_full_section]`);
                }
            },
            {
                text: 'Tabs',
                icon: 'fa fa-list-alt',
                onclick: function() {
                    editor.insertContent(`[soc_tabs][soc_tab title="Tab title"]Tab Content[/soc_tab][soc_tab title="Tab title"]Tab Content[/soc_tab][/soc_tabs]`);
                }
            },
            {
                text: 'Toggles',
                icon: 'fa fa-list',
                onclick: function() {
                    editor.insertContent(`[soc_toggles][soc_toggle title="Toggle title"]Toggle Content[/soc_toggle][soc_toggle title="Toggle title"]Toggle Content[/soc_toggle][/soc_toggles]`);
                }
            },
            {
                text: 'Timer',
                icon: 'fa fa-clock-o',
                onclick: function() {
                    editor.insertContent(`[soc_timer seconds="5"]Content[/soc_timer]`);
                }
            },
			 {
                text: 'Browser',
                icon: 'fa fa-chrome',
                onclick: function() {
                    editor.insertContent(`[soc_show browser="browser-chrome"]Show Chrome Content Only[/soc_show] [soc_hide browser="browser-edge"]Hide This Content In Edge Browsers[/soc_hide]`);
                }
            },
            {
                text: 'Posts',
                icon: 'fa fa-list',
                onclick: function() {
                    editor.insertContent(`[soc_posts columns="1" num_posts="4" style="1" date_meta="0"]`);
                }
            },
            {
                text: 'Info Box',
                icon: 'fa fa-info-circle',
                onclick: function() {
                    editor.insertContent(`[soc_info_box image="IMAGE_URL" button_url="BUTTON_URL" button_text="Read More" max_width="300px"]Main content for the info box[/soc_info_box]`);
                }
            },
            {
                text: 'Progress bar',
                icon: 'fa fa-minus',
                onclick: function() {
                    editor.insertContent(`[soc_progress_bar amount="50" color="#000" title="The Title"]`);
                }
            },
            {
                text: 'Counter',
                icon: 'fa fa-plus',
                onclick: function() {
                    editor.insertContent(`[soc_counter icon="pie-chart" color="#000" align="left" font_size="80" number="100" title="The Counter Title"]`);
                }
            },
            {
                text: 'Social Icons',
                icon: 'fa fa-twitter',
                onclick: function() {
                    editor.insertContent(`[soc_social color="#000" align="left" twitter="http://twitter.com" facebook="http://facebook.com" youtube="http://youtube.com"]`);
                }
            },
            {
                text: 'Timeline',
                icon: 'fa fa-clock-o',
                onclick: function() {
                    editor.insertContent(`[soc_timeline][soc_timeline_item date="July 1st, 2018" title="The title"]This is the content[/soc_timeline_item][soc_timeline_item date="July 1st, 2018" title="The title"]This is the content[/soc_timeline_item][/soc_timeline]`);
                }
            },
            {
                text: 'Accordion Menu',
                icon: 'fa fa-list',
                onclick: function() {
                    editor.insertContent(`[soc_accordion_menu menu="NUMERIC_ID"]`);
                }
            },
			{
                text: 'In Post Menu',
                icon: 'fa fa-bars',
                onclick: function() {
                    editor.insertContent(`[soc_menu name="EnterMenuNameHere"]`);
                }
            },
            {
                text: 'Login Form',
                icon: 'fa fa-sign-in',
                onclick: function() {
                    editor.insertContent(`[soc_login_form redirect="FULL_URL"][soc_member]You are already logged in.[/soc_member]`);
                }
            },
            {
                text: 'Register Form',
                icon: 'fa fa-user-plus',
                onclick: function() {
                    editor.insertContent(`[soc_register_form redirect="FULL_URL"][soc_member]You are already registered.[/soc_member]`);
                }
            },
            {
                text: 'User Shortcodes',
                icon: 'fa fa-user',
                onclick: function() {
                    editor.insertContent(`User Email: [soc_user_email] User DisplayName: [soc_user_displayname] User First Name: [soc_user_firstname] User Last Name: [soc_user_lastname] User ID: [soc_user_id] `);
                }
            },
            {
                text: 'Align',
                icon: 'fa fa-align-left',
                onclick: function() {
                    editor.insertContent(`[soc_align align="center"] you can align left, center and right and use max-width values too[/soc_align]`);
                }
            },
            {
                text: 'Video',
                icon: 'fa fa-play',
                onclick: function() {
                    editor.insertContent(`[soc_align align="center"]Delete this line after reading.. This is the same code inserted by the Media button, but I added this to save a step when adding S3 videos and centering them. Replace src with full video url and poster with full cover image url and you'll have a responsive centered video. [video src="full-video-url-path.mp4" poster="full-cover-image-url.jpg" width="1280" height="720" autoplay="false" preload="none"][/soc_align]`);
                }
			},
			 {
                text: 'Big Search',
                icon: 'fa fa-search',
                onclick: function() {
                    editor.insertContent(`[soc_big_search]`);
                }
			},
			 {
                text: 'Last Modified',
                icon: 'fa fa-calendar',
                onclick: function() {
                    editor.insertContent(`Use [soc_last_modified] or any format [soc_last_modified format="Y-m-d"]`);
                }
			},
				 {
                text: 'Div Elements',
                icon: 'fa fa-arrows-h',
                onclick: function() {
                    editor.insertContent(`[soc_element tag="div" class="my-class" id="my-id"]Use this code to make custom div or span classes using shortcodes[/soc_element]`);
                }
            }
        ];

        editor.addButton( 'soc_shortcodes', {
            title: 'Socrates ShortCodes',
            type:  'menubutton',
            image: `${baseURL}/assets/img/socrates-icon.png`,
            menu: groups
        });
    });
})();
