<?php

// Stop direct access
if ( ! defined('ABSPATH') ) die( 'Access Denied.' );

// Global vars
define( 'SOC_CURRENT_VERSION', '1.60');
define( 'SOC_PATH', dirname(__FILE__));
define( 'SOC_FILE', SOC_PATH . DIRECTORY_SEPARATOR . 'socrates.php');
define( 'SOC_URL', trailingslashit( plugin_dir_url( __FILE__ )) );


/**
 * Enqueue admin scripts
 *
 * @since 1.0
 */
function socrates_plugin_admin_scripts( $slug ) {

	// Get current theme
	$current_theme = wp_get_theme();
	$current_theme = $current_theme->template;

	// JS
	wp_enqueue_script( 'soc-tiny', SOC_URL . 'assets/js/global.js', array( 'jquery' ), SOC_CURRENT_VERSION, true );

	// CSS - if socrates or speaker theme
		if ( $current_theme == 'socrates-v5' || $current_theme == 'speaker-theme' ) {
		wp_enqueue_style( 'soc-font-awesome', get_template_directory_uri() . '/css/fonts/font-awesome/font-awesome.css' );
		wp_enqueue_style( 'soc-global', SOC_URL . 'assets/css/global.css' );

	// CSS - if not socrates or speaker theme
	} else {
		wp_enqueue_style( 'soc-font-awesome', SOC_URL . 'assets/css/vendor/font-awesome.min.css' );
		wp_enqueue_style( 'soc-global', SOC_URL . 'assets/css/global.css' );
	}

} add_action( 'admin_enqueue_scripts', 'socrates_plugin_admin_scripts' );

/**
 * Enqueue scripts
 *
 * @since 1.0
 */
function socrates_plugin_scripts() {

	// Get current theme
	$current_theme = wp_get_theme();
	$current_theme = $current_theme->template;

	// Get option
	$options = get_option( 'soc_custom_codes' );

	// Gutenberg CSS
	if ( is_array( $options ) && isset( $options['soc_function_disable_gutenberg_css'] ) && $options['soc_function_disable_gutenberg_css'] == 'on' ) {
		wp_dequeue_style( 'wp-block-library' );
	}

	// JS
	if ( is_array( $options ) && isset( $options['soc_function_disable_front_js'] ) && $options['soc_function_disable_front_js'] == 'on' ) {
		// do not load the front.js file
	} else {
		wp_enqueue_script( 'soc-front', SOC_URL . 'assets/js/front.min.js', array( 'jquery' ), SOC_CURRENT_VERSION, true );
	}

	// CSS - if socrates theme or speaker theme
	if ( $current_theme == 'socrates-v5' || $current_theme == 'speaker-theme' ) {
		
		
	// CSS - if not socrates theme or speaker theme
	} else {
		
		if ( is_array( $options ) && isset( $options['soc_function_disable_font_awesome'] ) && $options['soc_function_disable_font_awesome'] == 'on' ) {
			// do not load the font awesome files
		} else {
			wp_enqueue_style( 'soc-font-awesome', SOC_URL . 'assets/css/vendor/font-awesome.min.css' );
		}

		wp_enqueue_style( 'soc-components', SOC_URL . 'assets/css/components.css' );

	}

} add_action( 'wp_enqueue_scripts', 'socrates_plugin_scripts' );

// include files
require_once SOC_PATH . '/models/soc_tinymce_buttons.php';
require_once SOC_PATH . '/models/soc_functions.php';
require_once SOC_PATH . '/models/soc_shortcodes.php';
require_once SOC_PATH . '/inc/admin.php';
require_once SOC_PATH . '/inc/post-options.php';
require_once SOC_PATH . '/inc/widget.accordion-menu.php';

if ( method_exists('MSOC_Tinymce_buttons', 'initialize') ) {
	call_user_func( array('MSOC_Tinymce_buttons', 'initialize') );
}

if ( method_exists('MSOC_Functions', 'initialize') ) {
	call_user_func( array('MSOC_Functions', 'initialize') );
}

if ( method_exists('MSOC_Shortcodes', 'initialize') ) {
	call_user_func( array('MSOC_Shortcodes', 'initialize') );
}
// Include Widget Visibility class unless it is already activated with Jetpack
if ( ! class_exists( 'Jetpack' ) || ! Jetpack::is_module_active( 'widget-visibility' ) ) {
	require_once SOC_PATH . '/inc/widget-visibility.php';
}
