<?php

if ( ! class_exists( 'MSOC_Functions' ) ) {

	class MSOC_Functions {

	    protected static $options = false;

		public static function initialize() {

            self::$options = get_option( 'soc_custom_codes' );
			$options = self::$options;

			if ( $options && !empty($options) ) {

				// Add Post Add before or after main content
			    add_filter( 'the_content', array('MSOC_Functions', 'add_post_ad_content') );

			    // filter for member only
			    add_filter( 'the_content', array( 'MSOC_Functions', 'members_only_check' ), 99999 );

				if ( isset($options['soc_custom_css']) && !empty($options['soc_custom_css']) ) {
					add_action('wp_head', array('MSOC_Functions', 'hook_css'));
				}

				if ( isset($options['soc_custom_header_code']) && !empty($options['soc_custom_header_code']) ) {
					add_action('wp_head', array('MSOC_Functions', 'hook_custom_header'));
				}

				if ( isset($options['soc_custom_footer_code']) && !empty($options['soc_custom_footer_code']) ) {
					add_action( 'wp_footer', array('MSOC_Functions', 'hook_custom_footer') );
				}

				if ( isset($options['soc_custom_after_post_code']) && !empty($options['soc_custom_after_post_code']) ) {
					add_action( 'the_content', array('MSOC_Functions', 'hook_custom_after_post') );
				}

				if ( isset( $options['soc_function_disable_emoji'] ) && $options['soc_function_disable_emoji'] == 'on' ) {
					remove_action( 'wp_head', 'print_emoji_detection_script', 7 );
					remove_action( 'wp_print_styles', 'print_emoji_styles' );
				}

				if ( isset( $options['soc_function_disable_version'] ) && $options['soc_function_disable_version'] == 'on' ) {
					remove_action('wp_head', 'wp_generator');
					add_filter('the_generator', '__return_empty_string');
				}

				if ( isset( $options['soc_membership_redirect'] ) && $options['soc_membership_redirect'] !== 'none' ) {
					add_action( 'template_redirect', array( 'MSOC_Functions', 'members_only_redirect' ) );
				}

				if ( isset( $options['soc_membership_redirect_logout'] ) && ! empty( $options['soc_membership_redirect_logout'] ) ) {
					add_filter( 'wp_logout', array( 'MSOC_Functions', 'redirect_logout' ) );
				}				

				if ( isset( $options['soc_membership_hide_toolbar'] ) && ! empty( $options['soc_membership_hide_toolbar'] ) ) {
					add_filter( 'show_admin_bar', array( 'MSOC_Functions', 'hide_toolbar' ) );
				}

			}

		}

		public static function add_post_ad_content( $content ) {

		    $options = self::$options;

		    $post_top    = '';
		    $post_bottom = '';
		    $position_top = 'soc_none';
		    $position_bottom = 'soc_none';
		    $top_ad_display_on = 'all';
		    $bottom_ad_display_on = 'all';

			if ( isset($options['soc_post_ad_top_pos']) && !empty($options['soc_post_ad_top_pos']) ) {
				$position_top = $options['soc_post_ad_top_pos'];
			}

			if ( isset($options['soc_post_ad_bot']) && !empty($options['soc_post_ad_bot']) ) {
				$position_bottom = $options['soc_post_ad_bot'];
			}

			if ( isset($options['soc_post_ad_content_top']) && !empty($options['soc_post_ad_content_top']) ) {
				$post_top = '<div class="soc_custom_post_ad soc_'.$position_top.'">' . $options['soc_post_ad_content_top'] . '</div>';
			}

			if ( isset($options['soc_post_ad_content_bottom']) && !empty($options['soc_post_ad_content_bottom']) ) {
			    $post_bottom = '<div class="soc_custom_post_ad soc_'.$position_bottom.'">' . $options['soc_post_ad_content_bottom'] . '</div>';
			}

			if ( isset( $options['soc_post_ad_top_display'] ) ) {
				$top_ad_display_on = $options['soc_post_ad_top_display'];
			}

			if ( isset( $options['soc_post_ad_bot_display'] ) ) {
				$bottom_ad_display_on = $options['soc_post_ad_bot_display'];
			}

			// remove ads if disabled
			if ( is_singular() && get_post_meta( get_the_ID(), '_socrates_plugin_monetize', true ) == 'hide' ) {
				$post_top = '';
				$post_bottom = '';
			}

			// remove ads if plain white
			if ( is_page_template( 'template-plain-white.php' ) ) {
				$post_top = '';
				$post_bottom = '';
			}

			// top ad display on
			if ( $top_ad_display_on == 'hide' || ( $top_ad_display_on !== 'all' && $top_ad_display_on !== get_post_type() ) ) {
				$post_top = '';
			}

			// bottom ad display on
			if ( $bottom_ad_display_on == 'hide' || ( $bottom_ad_display_on !== 'all' && $bottom_ad_display_on !== get_post_type() ) ) {
				$post_bottom = '';
			}

			$custom_content = do_shortcode( $post_top ) . $content . do_shortcode( $post_bottom );

            return $custom_content;
		}

		public static function members_only_check( $content ) {

		    $options = self::$options;

		    if ( is_singular() && is_main_query() && in_the_loop() ) {

		    	if ( get_post_meta( get_the_ID(), '_socrates_plugin_members_only', true ) && ! is_user_logged_in() ) {

					$output = '';
					$output .= '<p class="soc-not-allowed-message">' . esc_html__( 'This content is restricted to members only, please log in using the form below.', 'socrates-plugin' ) . '</p>';
					$output .= '[soc_login_form]'; 
					return do_shortcode( $output );

				}

		    }

		    return $content;
		    
		}

		public static function members_only_redirect() {

			$options = self::$options;

			$redirect_id = $options['soc_membership_redirect'];
			$redirect_url = get_permalink( $options['soc_membership_redirect'] );

			$post_id = get_queried_object_id();

			if ( $post_id !== 0 && get_post_meta( $post_id, '_socrates_plugin_members_only', true ) && ! is_user_logged_in() ) {
				wp_redirect( esc_url( $redirect_url ) );
			}

		}

		public static function redirect_logout() {

			$options = self::$options;

			$redirect_url = $options['soc_membership_redirect_logout'];

			wp_redirect( $redirect_url );
			exit();

		}

		public static function hide_toolbar( $default ) {

			if ( ! is_user_logged_in() || ! current_user_can( 'manage_options' ) ) {
				return false;
			}
			return $default;

		}

		public static function save_custom_codes() {
			return;
		}

		public static function hook_css() {
			$options = get_option( 'soc_custom_codes' );
            echo "<style>" . $options['soc_custom_css'] . "</style>";
		}

		public static function hook_custom_header() {
			$options = get_option( 'soc_custom_codes' );
			echo $options['soc_custom_header_code'];
		}

		public static function hook_custom_footer() {
			$options = get_option( 'soc_custom_codes' );
			echo $options['soc_custom_footer_code'];
		}

		public static function hook_custom_after_post( $content ) {

			if ( is_singular( 'post' ) && in_the_loop() && is_main_query() ) {

				global $wp_the_query;
				global $wp_query;

				$current_ID = get_the_ID();
				$queried_ID = false;
				if ( isset( $wp_the_query->queried_object_id ) ) {
					$queried_ID = $wp_the_query->queried_object_id;
				}

				if ( $current_ID == $queried_ID ) {
					$options = get_option( 'soc_custom_codes' );
					$content .= '<div class="soc_after_post">' . $options['soc_custom_after_post_code'] . '</div>';
				}

			}

			return $content;

		    
		}

	}
}

if ( ! function_exists( 'socrates_browser_body_class' ) ) {

	/**
	 * Adds body classes based on device
	 *
	 * @since 1.0
	 */
	function socrates_browser_body_class( $classes ) {

		global $is_gecko, $is_IE, $is_opera, $is_safari, $is_chrome, $is_edge, $is_iphone;
		
		if( ! wp_is_mobile() ) {

			if($is_gecko) $classes[] = 'browser-gecko';
			elseif($is_opera) $classes[] = 'browser-opera';
			elseif($is_safari) $classes[] = 'browser-safari';
			elseif($is_chrome) $classes[] = 'browser-chrome';
			elseif($is_edge) $classes[] = 'browser-edge';
			elseif($is_IE) $classes[] = 'browser-ie';
			else $classes[] = 'browser-unknown';

		} else {

	    	if($is_iphone) $classes[] = 'browser-ios';
	        elseif(strpos($_SERVER['HTTP_USER_AGENT'], 'Android') !== false) $classes[] = 'browser-android';

		}

		return $classes;

	}

} add_filter( 'body_class', 'socrates_browser_body_class' );

if ( ! function_exists( 'socrates_plugin_login_fail' ) ) {

	/** 
	 * Redirect on login fail
	 *
	 * @since 1.51
	 */
	function socrates_plugin_login_fail( $username ) {

		$referrer = $_SERVER['HTTP_REFERER']; 
		if ( ! empty( $referrer ) && ! strstr( $referrer, 'wp-login' ) && ! strstr( $referrer,'wp-admin' ) ) {
			wp_redirect( add_query_arg( 'soc_login', 'failed', $referrer ) );
			exit;
		}

	}

} add_action( 'wp_login_failed', 'socrates_plugin_login_fail' );

if ( ! function_exists( 'socrates_plugin_exclude_from_search' ) ) {

	/** 
	 * Exclude from searrch
	 *
	 * @since 1.51
	 */
	function socrates_plugin_exclude_from_search( $query ) {

		// get main ( global ) query
		global $wp_the_query;

		// make sure current query is the same as the main query
		// that the query purpose is search
		// and that we are not in the admin
		if ( $query === $wp_the_query && $query->is_search() && ! is_admin() ) {			

			// tax query to exclude posts/pages with the meta value
			$meta_query = array(
				array(
					'key' => '_socrates_plugin_hide_from_search',
					'compare' => 'NOT EXISTS',
				)
			);

			// apply the meta query
			$query->set( 'meta_query', $meta_query );

		}

	}

} add_action( 'pre_get_posts', 'socrates_plugin_exclude_from_search' );

if ( ! function_exists( 'socrates_plugin_noindex_nofollow' ) ) {

	/** 
	 * Add noindex nofollow to pages
	 *
	 * @since 1.51
	 */
	function socrates_plugin_noindex_nofollow() {

		if ( is_singular() ) {
			
			global $post;
			if ( $hide_from_search = get_post_meta( $post->ID, '_socrates_plugin_hide_from_search', true ) ) {
				echo '<meta name="robots" content="noindex,nofollow"/>';
			}

		}

	}

} add_action( 'wp_head', 'socrates_plugin_noindex_nofollow', 1 );

if ( ! function_exists( 'socrates_plugin_register_form_process' ) ) {

	/**
	 * Handles registration process
	 *
	 * @since 1.0
	 */
	function socrates_plugin_register_form_process() {

		/**
		 * Process registration
		 */
		$socrates_register_errors = array();
		global $socrates_register_errors;
		$success = false;
		if ( isset( $_POST['soc_register_submit'] ) ) {			

			// verify nonce
			$nonce_verified = false;
			if ( wp_verify_nonce( $_POST['soc_register_nonce'], 'soc_register' ) ) {
				$nonce_verified = true;
			}

			// make sure values are supplied
			if ( ! $nonce_verified ) {

				$socrates_register_errors[] = esc_html__( 'Session expired. Please try again.', 'socrates-plugin' );

			} else if ( empty( $_POST['soc_register_username'] ) || empty( $_POST['soc_register_email'] ) || empty( $_POST['soc_register_password'] ) ) {
				
				$socrates_register_errors[] = esc_html__( 'All fields are required.', 'socrates-plugin' );

			} else {

				// get data
				$username = sanitize_user( $_POST['soc_register_username'], true );
				$email = sanitize_email( $_POST['soc_register_email'] );
				$password = $_POST['soc_register_password'];
				$first_name = false;
				if ( ! empty( $_POST['soc_register_first_name'] ) ) {
					$first_name = $_POST['soc_register_first_name'];
				}
				$last_name = false;
				if ( ! empty( $_POST['soc_register_last_name'] ) ) {
					$last_name = $_POST['soc_register_last_name'];
				}

				// validate username length
				if ( strlen( $username ) < 4 ) {
					$socrates_register_errors[] = esc_html__( 'Username must be at least 4 characters.', 'socrates-plugin' );
				}

				// validate password length
				if ( strlen( $password ) < 8 ) {
					$socrates_register_errors[] = esc_html__( 'Password must be at least 8 characters and contain at least one number.', 'socrates-plugin' );
				}

				if( preg_match( '/[0-9]/', $password ) === 0 ) {
					$socrates_register_errors[] = esc_html__( 'Password must contain a number ( 0-9 ).', 'socrates-plugin' );	
				}

				if( preg_match( '/[a-z]/', $password ) === 0 ) {
					$socrates_register_errors[] = esc_html__( 'Password must contain a character ( a-z ).', 'socrates-plugin' );	
				}
				if( preg_match( '/[A-Z]/', $password ) === 0 ) {
					$socrates_register_errors[] = esc_html__( 'Password must contain a character ( A-Z ).', 'socrates-plugin' );	
				}
		
				// validate email
				if ( ! is_email( $email ) ) {
					$socrates_register_errors[] = esc_html__( 'Must provide a valid email address.', 'socrates-plugin' );	
				}

				// if no errors so far let's proceed
					if ( empty( $socrates_register_errors ) )  {

					$user_data = array(
						'user_login' => $username,
						'user_pass' => $password,
						'user_email' => $email,
					);

					if ( isset( $_POST['soc_register_r_id'] ) ) {
						$user_role_id = $_POST['soc_register_r_id'];
						$role_ids = get_option( 'soc_user_role_ids' );
						foreach ( $role_ids as $role_name => $role_id ) {
							if ( $role_id == $user_role_id ) {
								$user_data['role'] = $role_name;
							}
						}
					}

					if ( $first_name ) {
						$user_data['first_name'] = $first_name;
					}
					if ( $last_name ) {
						$user_data['last_name'] = $last_name;
					}
					
					$insert_user = wp_insert_user( $user_data );

					if ( is_wp_error( $insert_user ) ) {
						foreach ( $insert_user->errors as $error ) {
							$socrates_register_errors[] = $error[0];
						}
					} else {
						$success = true;
					}

				}

			}

			if ( $success ) {

				$options = get_option( 'soc_custom_codes' );
				$should_send_email = true;
				if ( is_array( $options ) && isset( $options['soc_membership_enable_email'] ) && $options['soc_membership_enable_email'] == 'off' ) {
					$should_send_email = false;
				}

				// send email to admin
				if ( $should_send_email ) {
				
					$blogname = wp_specialchars_decode(get_option('blogname'), ENT_QUOTES);
					$message  = sprintf( esc_html__( 'New user registration on your site %s:', 'socrates-plugin' ), $blogname ) . "\r\n\r\n";
					$message .= sprintf( esc_html__( 'Username: %s', 'socrates-plugin' ), $username ) . "\r\n\r\n";
					$message .= sprintf( esc_html__( 'Email: %s', 'socrates-plugin' ), $email ) . "\r\n";
					$email_notification = array(
						'to'      => get_option( 'admin_email' ),
						'subject' => esc_html__( '[%s] New User Registration', 'socrates-plugin' ),
						'message' => $message,
						'headers' => '',
					);
					@wp_mail(
						$email_notification['to'],
						wp_specialchars_decode( sprintf( $email_notification['subject'], $blogname ) ),
						$email_notification['message'],
						$email_notification['headers']
					);

				}

				// sign in the user
				wp_signon( array(
					'user_login' => $username,
					'user_password' => $password,
					'remember' => true,
				), is_ssl() );

				// redirect
				wp_redirect( esc_url( $_POST['soc_register_redirect'] ) );

			}

		}

	}

} add_action( 'template_redirect', 'socrates_plugin_register_form_process' );

// remove version from scripts and styles
function socrates_plugin_remove_enqueue_versions( $src ) {

	$options = get_option( 'soc_custom_codes' );

	if ( is_array( $options ) && isset( $options['soc_function_disable_version'] ) && $options['soc_function_disable_version'] == 'on' ) {
		if ( strpos($src, 'ver=') ) {
			$src = remove_query_arg( 'ver', $src );
		}
	}
	return $src;

}
add_filter( 'style_loader_src', 'socrates_plugin_remove_enqueue_versions', 9999 );
add_filter( 'script_loader_src', 'socrates_plugin_remove_enqueue_versions', 9999 );